Index: trunk/ippToPsps/src/Batch.h
===================================================================
--- trunk/ippToPsps/src/Batch.h	(revision 31015)
+++ trunk/ippToPsps/src/Batch.h	(revision 31025)
@@ -18,5 +18,5 @@
 #include <dvo_util.h>
 
-#include "Config.h"
+#include "FitsGenerator.h"
 #include "Fits.h"
 #include "InitData.h"
@@ -34,19 +34,19 @@
 
     // fields
-    char surveyType[10];        // the survey type, eg 3PI, MD01, STS, SSS
-    int8_t surveyID;            // survey ID
-    char fitsInPath[1000];      // path to FITS input
-    char resultsPath[1000];     // path to results file
-    xmlDocPtr resultsXmlDoc;    // pointer to XML document for results
-    uint16_t numOfInputFiles;   // number of input files
-    char** inputFiles;          // array of input file names
-    Fits *fitsOut;              // output FITS file
-    pmConfig* pmconfig;         // pmConfig
-    dvoConfig* dvoConfig;       // dvo database
-    Config* config;             // Config object
-    InitData* initData;         // InitData object
-    char todaysDate[20];        // today's date
-    int exitCode;               // ps exit code
-    bool testMode;              // test mode boolean
+    char surveyType[10];           // the survey type, eg 3PI, MD01, STS, SSS
+    int8_t surveyID;               // survey ID
+    char fitsInPath[1000];         // path to FITS input
+    char resultsPath[1000];        // path to results file
+    xmlDocPtr resultsXmlDoc;       // pointer to XML document for results
+    uint16_t numOfInputFiles;      // number of input files
+    char** inputFiles;             // array of input file names
+    Fits *fitsOut;                 // output FITS file
+    pmConfig* pmconfig;            // pmConfig
+    dvoConfig* dvoConfig;          // dvo database
+    FitsGenerator* fitsGenerator;  // FitsGenerator object
+    InitData* initData;            // InitData object
+    char todaysDate[20];           // today's date
+    int exitCode;                  // ps exit code
+    bool testMode;                 // test mode boolean
 
     // methods
